==> blimbo-1.0-sources.jar: blimbo/items/ModItems.java <==
package blimbo.items;

import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroupEntries;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_10124;
import net.minecraft.class_10132;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1304;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_2960;
import net.minecraft.class_3417;
import net.minecraft.class_5321;
import net.minecraft.class_7706;
import net.minecraft.class_7924;
import net.minecraft.class_9886;
import blimbo.blimbo;

import java.util.List;
import java.util.function.Function;

public class ModItems {


    public static class_10124.class_10125 drink() {
        return class_10124.method_62850().method_62852(0.4F).method_62853(class_1839.field_8946).method_62855(class_3417.field_15075).method_62856(false);
    }
    public class ConsumableComponents {
        public static final class_10124 CUSTOM_ITEM2;


        static {
            CUSTOM_ITEM2= drink().method_62854(new class_10132(List.of(new class_1293(class_1294.field_5910, 600, 3), new class_1293(class_1294.field_5904, 600, 3), new class_1293(class_1294.field_5921, 1, 0)))).method_62851();
        }
    }

    public class FoodComponent {
        public static final net.minecraft.class_4174 CUSTOM_ITEM2;


        static {
            CUSTOM_ITEM2= new net.minecraft.class_4174(1,1,true);
        }
    }

    public static class_1792 registerItem(String name, Function<class_1792.class_1793, class_1792> factory, class_1792.class_1793 settings) {
        final class_5321<class_1792> registerkey =  class_5321.method_29179(class_7924.field_41197, class_2960.method_60655(blimbo.MOD_ID, name));
        return class_1802.method_51348(registerkey, factory, settings);
    }

    public static final class_1792 CUSTOM_ITEM = registerItem("custom_item", class_1792::new, new class_1792.class_1793().method_62833(FoodComponent.CUSTOM_ITEM2,ConsumableComponents.CUSTOM_ITEM2).method_62832(35));
    public static final class_1792 WARDEN = registerItem(
            "final_gambit",
            class_1792::new,
            new class_1792.class_1793()
                    .method_62833(FoodComponent.CUSTOM_ITEM2, TotemFunctions.ConsumableComponents.MAHORAGA)
                    .method_62832(40)
    );


    public static final class_1792 LIGHTNING = registerItem(
            "thunderous_totem",
            class_1792::new,
            new class_1792.class_1793()
                    .method_62833(FoodComponent.CUSTOM_ITEM2, ThunderFunctions.ConsumableComponents.TTOTEM)
                    .method_62832(30)
    );

    public static final class_1792 HONEY = registerItem("beekeepers_totem", class_1792::new, new class_1792.class_1793().method_62833(FoodComponent.CUSTOM_ITEM2,BeeFunctions.ConsumableComponents.BUMBLE).method_62832(40));
    public static final class_1792 BLIMBO = registerItem("blimbo", class_1792::new, new class_1792.class_1793().method_63682(class_1304.field_6169));
    public static final class_1792 NEGATIVE = registerItem("negative_blade_cosmetic", class_1792::new, new class_1792.class_1793());
    public static final class_1792 SPEAR = registerItem("amethyst_spear_cosmetic", class_1792::new, new class_1792.class_1793());
    public static final class_1792 GAMBLING = registerItem("gambling_buddy", class_1792::new, new class_1792.class_1793().method_62833(FoodComponent.CUSTOM_ITEM2,GamblingFunctions.ConsumableComponents.GAMBLE).method_62832(3));
    public static final class_1792 WATER = registerItem("totem_of_the_seas", class_1792::new, new class_1792.class_1793().method_66333(class_9886.field_52590,6.5f,0.6f));


    private static void customIngredients(FabricItemGroupEntries entries) {
        entries.method_45421(CUSTOM_ITEM);
        entries.method_45421(WARDEN);
        entries.method_45421(HONEY);
        entries.method_45421(BLIMBO);
        entries.method_45421(GAMBLING);
        entries.method_45421(WATER);
        entries.method_45421(LIGHTNING);
        entries.method_45421(NEGATIVE);
        entries.method_45421(SPEAR);
    }


    public static void registerModItems() {
        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41061).register(ModItems::customIngredients);
    }
}

==> blimbo-1.3-sources.jar: blimbo/items/ModItems.java <==
package blimbo.items;

import net.fabricmc.fabric.api.itemgroup.v1.FabricItemGroupEntries;
import net.fabricmc.fabric.api.itemgroup.v1.ItemGroupEvents;
import net.minecraft.class_10124;
import net.minecraft.class_10132;
import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1304;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_2960;
import net.minecraft.class_3417;
import net.minecraft.class_5321;
import net.minecraft.class_7706;
import net.minecraft.class_7924;
import net.minecraft.class_9886;
import blimbo.blimbo;

import java.util.List;
import java.util.function.Function;

public class ModItems {


    public static class_10124.class_10125 drink() {
        return class_10124.method_62850().method_62852(0.4F).method_62853(class_1839.field_8946).method_62855(class_3417.field_15075).method_62856(false);
    }
    public class ConsumableComponents {
        public static final class_10124 CUSTOM_ITEM2;


        static {
            CUSTOM_ITEM2= drink().method_62854(new class_10132(List.of(new class_1293(class_1294.field_5910, 600, 3), new class_1293(class_1294.field_5904, 600, 3), new class_1293(class_1294.field_5921, 1, 0)))).method_62851();
        }
    }

    public class FoodComponent {
        public static final net.minecraft.class_4174 CUSTOM_ITEM2;


        static {
            CUSTOM_ITEM2= new net.minecraft.class_4174(1,1,true);
        }
    }

    public static class_1792 registerItem(String name, Function<class_1792.class_1793, class_1792> factory, class_1792.class_1793 settings) {
        final class_5321<class_1792> registerkey =  class_5321.method_29179(class_7924.field_41197, class_2960.method_60655(blimbo.MOD_ID, name));
        return class_1802.method_51348(registerkey, factory, settings);
    }

    public static final class_1792 CUSTOM_ITEM = registerItem("custom_item", class_1792::new, new class_1792.class_1793().method_62833(FoodComponent.CUSTOM_ITEM2,ConsumableComponents.CUSTOM_ITEM2).method_62832(35));
    public static final class_1792 WARDEN = registerItem(
            "final_gambit",
            class_1792::new,
            new class_1792.class_1793()
                    .method_62833(FoodComponent.CUSTOM_ITEM2, TotemFunctions.ConsumableComponents.MAHORAGA)
                    .method_62832(40)
    );


    public static final class_1792 LIGHTNING = registerItem(
            "thunderous_totem",
            class_1792::new,
            new class_1792.class_1793()
                    .method_62833(FoodComponent.CUSTOM_ITEM2, ThunderFunctions.ConsumableComponents.TTOTEM)
                    .method_62832(30)
    );

    public static final class_1792 HONEY = registerItem("beekeepers_totem", class_1792::new, new class_1792.class_1793().method_62833(FoodComponent.CUSTOM_ITEM2,BeeFunctions.ConsumableComponents.BUMBLE).method_62832(40));
    public static final class_1792 BLIMBO = registerItem("blimbo", class_1792::new, new class_1792.class_1793().method_63682(class_1304.field_6169));
    public static final class_1792 NEGATIVE = registerItem("negative_blade_cosmetic", class_1792::new, new class_1792.class_1793());
    public static final class_1792 SPEAR = registerItem("amethyst_spear_cosmetic", class_1792::new, new class_1792.class_1793());
    public static final class_1792 GAMBLING = registerItem("gambling_buddy", class_1792::new, new class_1792.class_1793().method_62833(FoodComponent.CUSTOM_ITEM2,GamblingFunctions.ConsumableComponents.GAMBLE).method_62832(3));
    public static final class_1792 WATER = registerItem("totem_of_the_seas", SeaTridentItem::new, new class_1792.class_1793().method_66333(class_9886.field_52590,4.5f,0.25f).method_62832(7.0F));
    public static final class_1792 SHOUT = registerItem("shout", ShoutItem::new, new class_1792.class_1793().method_62832(5));
    public static final class_1792 PRISMATIC = registerItem("prismatic", PrismTridentItem::new, new class_1792.class_1793().method_62832(5));

    private static void customIngredients(FabricItemGroupEntries entries) {
        entries.method_45421(CUSTOM_ITEM);
        entries.method_45421(WARDEN);
        entries.method_45421(HONEY);
        entries.method_45421(BLIMBO);
        entries.method_45421(GAMBLING);
        entries.method_45421(WATER);
        entries.method_45421(LIGHTNING);
        entries.method_45421(NEGATIVE);
        entries.method_45421(SPEAR);
        entries.method_45421(SHOUT);
        entries.method_45421(PRISMATIC);
    }


    public static void registerModItems() {
        ItemGroupEvents.modifyEntriesEvent(class_7706.field_41061).register(ModItems::customIngredients);
    }
}
